#!/bin/bash

REAL_IP_CONFIG="/etc/nginx/conf.d/real_ip.conf"

cert_gen(){
    openssl genrsa -out /etc/nginx/cert/server.key 2048
    openssl req -new -out /etc/nginx/cert/server.csr -key /etc/nginx/cert/server.key -subj /CN=localhost
    openssl x509 -req -days 3600 -in /etc/nginx/cert/server.csr -signkey /etc/nginx/cert/server.key -out /etc/nginx/cert/server.crt
}

if [ "${EDOC2_SCALE}" == "true" ]; then
    /opt/nginx/edoc2-scale.sh &
fi

if [ -n "${REAL_IP}" ];then
       echo "real_ip_header    X-Forwarded-For;" > ${REAL_IP_CONFIG}
       echo "real_ip_recursive on;" >> ${REAL_IP_CONFIG}
   for rip in $(echo ${REAL_IP}|tr , ' ')
   do
       echo "set_real_ip_from ${rip};" >> ${REAL_IP_CONFIG}
   done
fi

if [ "${REGION}" == "true"  ];then
   NGINX_CONFIG_80="nginx_region_80.conf"
   NGINX_CONFIG_SSL="nginx_region_ssl.conf"
else 
   NGINX_CONFIG_80="nginx_80.conf"
   NGINX_CONFIG_SSL="nginx_ssl.conf"
fi


if [ "${SSL}" != "true" ];then
    cp -rf /opt/nginx/${NGINX_CONFIG_80} /etc/nginx/conf.d/default.conf
else
    if [ $(ls /etc/nginx/cert/*.crt 2> /dev/null) ];then
        SSL_CERT=$(ls /etc/nginx/cert/*.crt)
        SSL_CERT_KEY=$(ls /etc/nginx/cert/*.key)
    else
        cert_gen
        SSL_CERT=$(ls /etc/nginx/cert/*.crt)
        SSL_CERT_KEY=$(ls /etc/nginx/cert/*.key)
    fi
    cp -rf /opt/nginx/${NGINX_CONFIG_SSL} /etc/nginx/conf.d/default.conf
    sed -i s%DOMAIN_NAME%${DOMAIN_NAME}%g /etc/nginx/conf.d/default.conf
    sed -i s%SSL_CERT%${SSL_CERT}%g /etc/nginx/conf.d/default.conf
    sed -i s%SSL_KEY%${SSL_CERT_KEY}%g /etc/nginx/conf.d/default.conf

fi

if [ "${REGION}" == "true"  ];then
  echo "REGION"
else
    if [ -z "${WF}" -o "${WF}" == "true"  ];then
          cat   << EOF >> /etc/nginx/conf.d/default.conf
    	     location /edoc2Flow-web {  
    		#proxy_redirect off;
    		proxy_set_header Host \$host;
    		proxy_set_header X-Real-IP \$remote_addr; 
    		proxy_set_header REMOTE-HOST \$remote_addr; 
    		proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
    		proxy_pass http://wf:8080/edoc2Flow-web/; 
    		index  index.html index.htm;
    		allow all;
        }
EOF
   fi

   if [ "${INSIGHT}" == "true" ];then
       cat <<  EOF >> /etc/nginx/conf.d/default.conf
                      location /insight/ {
                      proxy_set_header Host \$host;
                      proxy_set_header X-Real-IP \$remote_addr; 
                      proxy_set_header REMOTE-HOST \$remote_addr; 
                      proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                      proxy_pass http://insight/; 
                      index  index.html index.htm;
                      allow all;
        } 
EOF
   fi

   if [ "${SEARCHENGINE}" == "true" ];then
       cat <<  EOF >> /etc/nginx/conf.d/default.conf
	location /search/ {
            proxy_set_header Host \$host;
            proxy_set_header X-Real-IP \$remote_addr; 
            proxy_set_header REMOTE-HOST \$remote_addr; 
            proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
            proxy_pass http://searchengine/search/; 
            allow all;
        } 
EOF
   fi

   if [ "${ICS}" == "true" ];then
       cat <<  EOF >> /etc/nginx/conf.d/default.conf
                      location /ics/ {
                      proxy_set_header Host \$host;
                      proxy_set_header X-Real-IP \$remote_addr; 
                      proxy_set_header REMOTE-HOST \$remote_addr; 
                      proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                      proxy_pass http://ics:8079/ics/; 
                      index  index.html index.htm;
                      allow all;
        } 
EOF
   fi

   if [ "${INGRAPH}" == "true" ];then
       cat <<  EOF >> /etc/nginx/conf.d/default.conf
                      location /ingraph/ {
                      proxy_set_header Host \$host;
                      proxy_set_header X-Real-IP \$remote_addr; 
                      proxy_set_header REMOTE-HOST \$remote_addr; 
                      proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                      proxy_pass http://ingraph:8080/inGraph/api/; 
                      index  index.html index.htm;
                      allow all;
        } 

       location /ingraph/front/ {
                      proxy_set_header Host \$host;
                      proxy_set_header X-Real-IP \$remote_addr; 
                      proxy_set_header REMOTE-HOST \$remote_addr; 
                      proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                      proxy_pass http://front/; 
                      index  index.html index.htm;
                      allow all;
        }
EOF
   fi

     if [ "${WORDTEMPLATE}" == "true" ];then
       cat <<  EOF >> /etc/nginx/conf.d/default.conf
                      location /wordtemplate/ {
                      proxy_set_header Host \$host;
                      proxy_set_header X-Real-IP \$remote_addr; 
                      proxy_set_header REMOTE-HOST \$remote_addr; 
                      proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                      proxy_pass http://wordtemplate/; 
                      index  index.html index.htm;
                      allow all;
        } 
EOF
   fi
     if [ "${UDCMGT}" == "true" ];then
       cat <<  EOF >> /etc/nginx/conf.d/default.conf
                      location /udcmgt/ {
                      proxy_set_header Host \$host;
                      proxy_set_header X-Real-IP \$remote_addr; 
                      proxy_set_header REMOTE-HOST \$remote_addr; 
                      proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                      proxy_pass http://udcmgt/; 
                      index  index.html index.htm;
                      allow all;
        } 
EOF
   fi
  if [ "${EDRMSCORE}" == "true" ];then
       cat <<  EOF >> /etc/nginx/conf.d/default.conf
                      location /edrmscore/ {
                      proxy_set_header Host \$host;
                      proxy_set_header X-Real-IP \$remote_addr; 
                      proxy_set_header REMOTE-HOST \$remote_addr; 
                      proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                      proxy_pass http://edrmscore/edrmscore/; 
                      index  index.html index.htm;
                      allow all;
        } 
EOF
   fi
fi


if [ "${WEBOFFICE}" == "true" ];then
     cat << EOF >> /etc/nginx/conf.d/default.conf
         location /6.1.0-83/ {
                proxy_pass http://weboffice_ip/6.1.0-83/;
                proxy_set_header Host \$http_host;
                proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                proxy_set_header X-Forwarded-Proto ${WEBOFFICE_PROTO:=http};
        	proxy_cache office_cache;
        	proxy_cache_key \$request_uri;
        	proxy_cache_methods GET HEAD;
        	proxy_cache_valid  200 304 302 24h;
        	proxy_cache_use_stale http_502;  
        	add_header X-Cache "\$upstream_cache_status from \$server_addr";
        }

        location  /coauthoring/CommandService.ashx {
            proxy_pass http://weboffice_ip/coauthoring/CommandService.ashx;
            proxy_set_header Host \$http_host;
            proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
            proxy_set_header X-Forwarded-Proto ${WEBOFFICE_PROTO:=http};
        	proxy_cache office_cache;
        	proxy_cache_key \$request_uri;
        	proxy_cache_methods GET HEAD;
        	proxy_cache_valid  200 304 302 24h;
        	proxy_cache_use_stale http_502;  
        	add_header X-Cache "\$upstream_cache_status from \$server_addr";
        }

        location /web-apps/ {
                proxy_pass http://weboffice_ip/web-apps/;
                proxy_set_header Host \$http_host;
                proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                proxy_set_header X-Forwarded-Proto ${WEBOFFICE_PROTO:=http};
        	proxy_cache office_cache;
        	proxy_cache_key \$request_uri;
        	proxy_cache_methods GET HEAD;
        	proxy_cache_valid  200 304 302 24h;
        	proxy_cache_use_stale http_502;  
        	add_header X-Cache "\$upstream_cache_status from \$server_addr";
        }
    location /cache/files/ {
                proxy_pass http://weboffice_ip/cache/files/;
                proxy_set_header Host \$http_host;
                proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                proxy_set_header X-Forwarded-Proto ${WEBOFFICE_PROTO:=http};
        	proxy_cache office_cache;
        	proxy_cache_key \$request_uri;
        	proxy_cache_methods GET HEAD;
        	proxy_cache_valid  200 304 302 24h;
        	proxy_cache_use_stale http_502;  
        	add_header X-Cache "\$upstream_cache_status from \$server_addr";
    }
        location /weboffice/ {
                proxy_pass http://weboffice_ip/welcome/;
                proxy_set_header Host \$http_host;
                proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                proxy_set_header X-Forwarded-Proto ${WEBOFFICE_PROTO:=http};
        	proxy_cache office_cache;
        	proxy_cache_key \$request_uri;
       		proxy_cache_methods GET HEAD;
	        proxy_cache_valid  200 304 302 24h;
	        proxy_cache_use_stale http_502;  
	        add_header X-Cache "\$upstream_cache_status from \$server_addr";
        }
    location /healthcheck {
                proxy_pass http://weboffice_ip/healthcheck;
                proxy_set_header Host \$http_host;
                proxy_set_header X-Forwarded-For \$proxy_add_x_forwarded_for;
                proxy_set_header X-Forwarded-Proto ${WEBOFFICE_PROTO:=http};
        	proxy_cache office_cache;
        	proxy_cache_key \$request_uri;
        	proxy_cache_methods GET HEAD;
        	proxy_cache_valid  200 304 302 24h;
        	proxy_cache_use_stale http_502;  
        	add_header X-Cache "\$upstream_cache_status from \$server_addr";
    }

    location ~ websocket$ {
		proxy_pass http://weboffice_ip;
        proxy_set_header Host \$http_host;
		proxy_http_version 1.1;    
		proxy_set_header Upgrade \$http_upgrade;    
        proxy_set_header X-Forwarded-Proto ${WEBOFFICE_PROTO:=http};
		proxy_set_header Connection "Upgrade";    
		proxy_set_header X-real-ip \$remote_addr;
		proxy_set_header X-Forwarded-For \$remote_addr;
		}
EOF
fi

echo '}'  >> /etc/nginx/conf.d/default.conf



/opt/nginx/nginx-config.sh &
/opt/nginx/nginx-transport-config.sh &
/opt/nginx/nginx-weboffice-config.sh &

sleep 5
nginx -g "daemon off;"
